@@ -87,7 +87,7 @@ class GroupShape(ShapeBase):
     def __init__(self, self_uri=None, alternate_links=None, name=None, width=None, height=None, alternative_text=None, alternative_text_title=None, hidden=None, x=None, y=None, z_order_position=None, shapes=None, fill_format=None, effect_format=None, line_format=None, type='GroupShape'):  # noqa: E501
         """GroupShape - a model defined in Swagger"""  # noqa: E501
         super(GroupShape, self).__init__(self_uri, alternate_links, name, width, height, alternative_text, alternative_text_title, hidden, x, y, z_order_position, shapes, fill_format, effect_format, line_format, type)
-        self.type: 'GroupShape'
+        self.type = 'GroupShape'
 
     def to_dict(self):
         """Returns the model properties as a dict"""
